import React$1 from 'react';

type InputConfigs = {
    /**
     * Placeholder text to display in the input field.
     * Optional property.
     */
    inputPlaceholder?: React.InputHTMLAttributes<HTMLInputElement>["placeholder"];
    /**
     * Tailwind CSS and Custom class for styling the input field.
     * Optional property.
     */
    inputClassName?: React.InputHTMLAttributes<HTMLInputElement>["className"];
    /**
     * Name attribute for the input field.
     * Optional property.
     */
    inputName?: React.InputHTMLAttributes<HTMLInputElement>["name"];
    /**
     * Format text for displaying input instructions or guidelines.
     * Optional property.
     */
    inputType?: React.InputHTMLAttributes<HTMLInputElement>["type"];
};
type HeaderConfigs = {
    /**
     * Tailwind CSS and Custom class for styling the header.
     * Optional property.
     */
    headerClassName?: string | undefined;
    /**
     * Title for the top of header.
     * This property is required.
     */
    headerTitle?: string;
};
type ListDetailsData = {
    /**
     * Icon representing the list details item.
     * This can be an SVG, image URL, or any other suitable format.
     * Optional property.
     */
    icon?: React.ReactNode;
    /**
     * Title for the list details item.
     * This property is required.
     */
    title: Required<string>;
    /**
     * Description providing additional information about the list details item.
     * Optional property.
     */
    description?: string;
    /**
     * Category classification for the list details item.
     * Optional property.
     */
    category?: string;
};

type AutoCompleteProps = {
    /**
     * Function to get list details asynchronously
     * @param data - The data for which details are to be fetched
     * @param signal - Optional AbortSignal for aborting the request
     * @returns A promise resolving to type T
     */
    getListDetails: ({ inputValue, signal, }: {
        inputValue?: string;
        signal: AbortSignal;
    }) => Promise<ListDetailsData[]>;
    /**
     * Represents configuration options for an input field.
     */
    inputConfigs?: InputConfigs;
    /**
     * Represents configuration options for a drawer header.
     */
    headerConfigs?: HeaderConfigs;
    /**
     * Callback function invoked when the value of the list details changes.
     * @param list The updated list details data.
     */
    onChangeValue?: (list: ListDetailsData) => void;
};
declare function AutoComplete({ getListDetails, headerConfigs, inputConfigs, onChangeValue, }: AutoCompleteProps): React$1.JSX.Element;

export { type ListDetailsData, AutoComplete as default };
